<!DOCTYPE html>
<?php

//
// ptiblogphp
//
// This is a simple blogging system, requires only standard PHP. All content
// is stored in filesystem (no database).
//
// Copyright (C) 2021 Mateusz Viste
// Published under the terms of the MIT license.
//

$PVER = '20210627';

// preinit a few global settings with default values
$ENTRIES_PER_PAGE = 5;
$ADMINPASS = '';
$ADMINLOGIN = '';
$TITLE = "MISSING TITLE";

include 'settings.php';

if (! empty($LANG)) {
  echo '<html lang="' . $LANG . '">' . "\n";
} else {
  echo '<html>' . "\n";
}
?>
  <head>
    <title><?php echo $TITLE; ?></title>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="generator" content="ptiblogphp/<?php echo $PVER; ?>">
    <link rel="stylesheet" type="text/css" href="style.css">
    <link rel="stylesheet" type="text/css" href="slide.css">
    <link rel="stylesheet" type="text/css" href="dropzone570/dropzone.min.css">
    <link rel="stylesheet" type="text/css" href="custom.css">
  </head>

  <body>
    <div class="banner">
      <h1><?php echo $TITLE; ?></h1>
    </div>

    <?php
      $isadmin = false;

      // funkcja ładująca listę artykułów
      function LadujArtykuly() {
        $r = array();
        $dirhandle = opendir('data');
        if (! $dirhandle) return($r);
        while (($entry = readdir($dirhandle)) !== false) {
          if ($entry[0] == '.') continue; // ignoruj ukryte pliki i katalogi oraz '.' i '..'
          if (is_dir('data/' . $entry)) continue;   // ignoruj katalogi
          $r[] = pathinfo($entry, PATHINFO_FILENAME);
        }
        closedir($dirhandle);
        arsort($r); // sortuj anty-alfanumerycznie
        return($r);
      }

      // ładuj listę plików z katalogu. Flaga:
      //   0 = wszystkie pliki
      //   1 = tylko zdjęcia
      //   2 = tylko nie-zdjęcia
      function ListaPlikow($artid, $flaga) {
        $r = array();
        $katalog = 'data/' . $artid;
        $dirhandle = opendir($katalog);
        if (! $dirhandle) return($r);
        while (($entry = readdir($dirhandle)) !== false) {
          if ($entry[0] == '.') continue; // ignoruj ukryte pliki i katalogi oraz '.' i '..'
          if (is_dir($katalog . '/' . $entry)) continue;   // ignoruj katalogi
          if (preg_match('/\.(jpg|jpeg|png)$/i', $entry)) {
            if ($flaga != 2) $r[$entry] = true;
          } else { // not a photo
            if ($flaga != 1) $r[$entry] = false;
          }
        }
        closedir($dirhandle);
        ksort($r); // sortuj alfanumerycznie
        return($r);
      }

      function LadujPlikLinii($plik) {
        $r = explode("\n", file_get_contents($plik));
        return($r);
      }

      function PaginationLink($p, $lastp) {
        if ($p != $lastp) return('./?p=' . $p);
        return('./');
      }

      // zwraca tablicę z listą stron dla paska paginacji
      // wartość 0 oznacza symbol '...'
      function ListaStronDoPaginacji($p, $maxp) {
        $r = array();
        if ($p == 0) $p = $maxp; // p=0 znaczy "ostatnia strona"
        $pierwsza = $p - 3;
        $ostatnia = $p + 3;
        while ($pierwsza < 1) {
          $pierwsza++;
          $ostatnia++;
        }
        while ($ostatnia > $maxp) {
          $ostatnia--;
          if ($pierwsza > 1) $pierwsza--;
        }
        // dodaj pierwszą stronę oraz symbol '...' jeśli potrzeba
        if ($pierwsza > 1) {
          $r[] = 1;
          $r[] = 0;
        } else {
          $r[] = $pierwsza;
        }
        // dodaj wszystkie 'środkowe' wartości
        for ($pp = $pierwsza + 1; $pp < $ostatnia; $pp++) $r[] = $pp;
        // dodaj ostatnią wartość, ew. poprzedzoną symbolem '...'
        if ($ostatnia < $maxp) {
          $r[] = 0;
          $r[] = $maxp;
        } else if ($ostatnia != $pierwsza) {
          $r[] = $ostatnia;
        }

        // jeśli tylko jedna strona to daj se spokój
        if (count($r) < 2) $r = array();

        return(array_reverse($r));
      }

      // ustaw locale (np. dla generowania dat)
      setlocale(LC_ALL, "fr_FR");

      // czytaj zmienne przekazane via get
      $p = 0;
      $action = "";
      $artid = "";
      if (!empty($_GET['p'])) $p = intval($_GET['p']);
      if (!empty($_GET['action'])) $action = $_GET['action'];
      if (!empty($_GET['artid'])) $artid = $_GET['artid'];
      if (!empty($_GET['zdjid'])) $zdjid = $_GET['zdjid'];

      // nadpisz zmienne jeśli dostalismy operację POST
      if (!empty($_POST['p'])) $p = intval($_POST['p']);
      if (!empty($_POST['action'])) $action = $_POST['action'];
      if (!empty($_POST['artid'])) $artid = $_POST['artid'];

      // inicjalizacja sesji
      session_set_cookie_params(3600 * 24 * 365); // set auth cookie lifetime to 1 year
      session_start();

      // czy dostałem hasło? jeśli tak, sprawdź czy cokolwiek warte
      if ((isset($_POST['password'])) && (isset($_POST['login']))) {
        if ((!empty($ADMINPASS)) && ($_POST['login'] === $ADMINLOGIN) && ($_POST['password'] === $ADMINPASS)) {
          $_SESSION['login'] = $_POST['login'];
        } else {
          echo '<p class="autherr">ERREUR D\'AUTHENTIFICATION</p>' . "\n";
        }
      }

      // prośba o logout?
      if ($action === 'logout') {
        session_destroy();
        unset($_SESSION);
        $action = '';
      }

      // admin?
      if ($_SESSION['login'] === $ADMINLOGIN) $isadmin = true;

      if (isset($_SESSION['login'])) {
        echo "<p class=\"bonjour\">{$_SESSION['login']} <a href=\"./?action=logout&amp;p={$p}\"><img src=\"padlockopen.svg\"></a></p>\n";
      } else {
        echo "<p class=\"bonjour\"><a href=\"./?action=login&amp;p={$p}\"><img src=\"padlockclosed.svg\"></a></p>\n";
      }

      echo '<div class="zawartosc">' . "\n";

      // wyświetl błąd jeśli nie-admin coś kombinuje
      if (! $isadmin) {
        if (($action === 'nowywpis') || ($action === 'dodajwpis')) {
          echo '<p class="autherr">FONCTION REFUSÉE, VEUILLEZ VOUS AUTHENTIFIER</p>' . "\n";
          $action = '';
        }
      }

      // dodanie nowego wpisu? (albo edycja istniejącego)
      if (($isadmin) && ($action === 'dodajwpis')) {
        if (empty($artid)) $artid = time();
        $artfile = 'data/' . $artid . '.txt';
        if (!is_dir('data')) {
          if (!mkdir('data')) echo "<!-- mkdir(data) error! -->\n"; // stwórz katalog danych jeśli jeszcze nie istnieje
        }
        $dh = fopen($artfile, 'w');
        fwrite($dh, trim($_POST['arttit']));
        fwrite($dh, "\n");
        fwrite($dh, trim($_POST['artbody']));
        fclose($dh);
        // empty art? (delete)
        if (empty(trim($_POST['arttit'])) && empty(trim($_POST['artbody'])) && empty(ListaPlikow($artid, 0))) {
          unlink("data/{$artid}.txt");
          if (is_dir("data/{$artid}")) rmdir("data/{$artid}");
        }
        $action = '';
      }

      if (($p == 0) && (empty($action))) {
        readfile("welcome.txt");
      } else if ($action === 'nowywpis') {
        echo "<p>Édition</p>\n";
      } else if ($action === 'login') {
        echo '<div class="authbox">' . "\n";
        echo '<div class="authimg"><img src="padlockclosed.svg"></div>' . "\n";
        echo '<div class="auth">' . "\n";
        echo '<form action="./?p=' . $p . '" method="post" class="auth">' . "\n";
        echo '<div class="authcred">' . "\n";
        echo 'utilisateur: <input type="text" name="login" id="login"><br>' . "\n";
        echo 'mot de passe: <input type="password" name="password" id="password"><br>' . "\n";
        echo "</div>\n";
        echo '<p><input type="submit" value="connexion"></p>' . "\n";
        echo "</form>\n";
        echo "</div>\n";
        echo "</div>\n";
        goto BOTTOM;
      }

      // załaduj skrypt simpleSlider carousel: https://github.com/michu2k/SimpleSlider
      echo '<script src="SimpleSlider-v.1.9.0/dist/simpleSlider.min.js"></script>' . "\n";

      // akcje adminowe
      if (($isadmin) && ($action === 'usunzdjecie')) {
        unlink("data/{$artid}/" . urldecode($zdjid));
        if (empty(ListaPlikow($artid, 0))) rmdir('data/' . $artid); // usuń katalog jeśli już nic w nim nie ma
        $action = 'zdjecia';
      }

      if (($isadmin) && ($action === 'nowywpis')) { // nowy wpis
        $art_title = '';
        $art_body = '';
        if (! empty($artid)) { // edycja istniejącego wpisu
          $plik = LadujPlikLinii("data/{$artid}.txt");
          $art_title = $plik[0];
          array_splice($plik, 0, 1);
          foreach ($plik as $l) {
            $art_body .= $l . "\n";
          }
        }
        echo '<form action="' . PaginationLink($p, -1) . '" method="post" class="nowywpis">' . "\n";
        echo "<div class=\"nowywpis\">\n";
        echo "<p>titre:</p>\n";
        if (! empty($artid)) {
          echo '<input type="hidden" id="artid" name="artid" value="' . $artid . '">' . "\n";
        }
        echo '<input type="hidden" id="action" name="action" value="dodajwpis">' . "\n";
        echo '<input type="text" id="arttit" name="arttit" value="' . htmlentities($art_title) . '">' . "\n";
        echo "<p>message:</p>\n";
        echo '<textarea name="artbody" id="artbody" rows="20">' . "\n";
        echo htmlentities($art_body);
        echo "</textarea>\n";
        echo "</div>\n";
        echo '<p style="text-align: center;"><a href="' . PaginationLink($p, -1) . '">annuler</a> <input type="submit" value="envoyer" style="width: auto;"></p>' . "\n";
        echo "</form>\n";
        goto BOTTOM;
      } else if (($isadmin) && ($action === 'zdjecia') && (! empty($artid))) { // zarządzanie zdjęciami
        echo "<p>Ajout de nouvelles photos:</p>\n";
        echo '<form action="./?artid=' . $artid . '&amp;action=uploadzdjecie" class="dropzone" id="formularzdropzone"></form>' . "\n";
        echo '<p class="admintool" style="text-align: center;"><a href="./?artid=' . $artid . '&amp;action=zdjecia">RAFRAICHIR</a> <a href="' . PaginationLink($p, -1) . '">RETOUR</a></p>' . "\n";
        echo '<script src="./dropzone570/dropzone.min.js"></script>' . "\n";
        echo '<script>Dropzone.options.formularzdropzone = {resizeWidth: 1600, resizeHeight: 1200, dictDefaultMessage: "Déposez vos photos ici"};</script>' . "\n";
        $lista_plikow = ListaPlikow($artid, 0);
        foreach ($lista_plikow as $zd => $flaga_zdj) {
          $icon = 'file.svg';
          if ($flaga_zdj) $icon = "data/{$artid}/" . rawurlencode($zd);
          echo "<div class=\"managezd\"><img src=\"{$icon}\" class=\"thumb\"><p>" . htmlentities($zd) . '</p><p>' . round(filesize("data/{$artid}/{$zd}") / 1024) . " KiB <a href=\"./?artid={$artid}&amp;action=usunzdjecie&amp;zdjid=" . rawurlencode($zd) . "\"><img src=\"trash.svg\" style=\"height: 1em; width: auto;\"></a></p></div>\n";
        }
        goto BOTTOM;
      } else if (($isadmin) && ($action === 'uploadzdjecie')) { // dropzone upload zdjęcia
        //$fh = fopen('log.txt', 'a');
        //fwrite($fh, "--- UPLOAD ---\n");
        if (!is_dir("data/{$artid}")) mkdir("data/{$artid}");
        foreach ($_FILES as $fname) {
        //  fwrite($fh, $fname['name'] . "\n");
          move_uploaded_file($fname['tmp_name'], "data/{$artid}/{$fname['name']}");
        }
        //fclose($fh);
      } else if (($isadmin) && ($p == 0)) { // nic szczególnego
        echo "<p class=\"admintool\"><a href=\"./?action=nowywpis\">+ nouvelle entrée</a></p>\n";
      }

      // wylistuj dostępne artykuły
      $arty = LadujArtykuly();
      $liczbastron = intval((count($arty) / $ENTRIES_PER_PAGE) + 0.9);
      if ($liczbastron < 1) $liczbastron = 1;
      if ($p > 0) array_splice($arty, 0, ($liczbastron - $p) * $ENTRIES_PER_PAGE); // usuń nieinteresujące wpisy PRZED
      array_splice($arty, $ENTRIES_PER_PAGE); // zostaw odpowiednią ilość wpisów do wyświetlenia
      $licznik = 0;

      foreach ($arty as $art) {
        $licznik++;
        $artcontent = LadujPlikLinii("data/{$art}.txt");
        echo "<div class=\"blogentry\">\n";
        if ($isadmin) {
          echo "<p class=\"admintool\"><a href=\"./?action=nowywpis&amp;artid={$art}&amp;p={$p}\"><img src=\"edit.svg\"></a></p>\n";
        }
        echo "<h2>{$artcontent[0]}</h2>\n";
        echo "<h3>rédigé le " . strftime("%A, %e %B %Y", $art) . "</h3>\n";
        foreach ($artcontent as $i => $artline) {
          if ($i == 0) continue; // skip art title (already rendered)
          echo '<p>' . htmlentities($artline) . "</p>\n";
        }
        // mamy jakieś załączniki? (nie zdjęcia)
        $lista_plikow = ListaPlikow($art, 2);
        if (!empty($lista_plikow)) {
          echo '<p>';
          foreach ($lista_plikow as $plik => $plik_flaga) {
            echo "<img src=\"file.svg\" style=\"height: 1em; width: auto;\"> <a href=\"data/{$art}/" . rawurlencode($plik) . "\">" . htmlentities($plik) . "</a> (" . round(filesize("data/{$art}/{$plik}") / 1024) . " KiB)<br>\n";
          }
          echo "</p>\n";
        }
        // SLAJDY START
        $lista_zdjec = ListaPlikow($art, 1);
        if (! empty($lista_zdjec)) {  // zdjęcia?
          echo '<div class="simple-slider simple-slider-' . $licznik . '">' . "\n";
          if (count($lista_zdjec) > 1) echo '  <div class="slider-wrapper">' . "\n";
          foreach ($lista_zdjec as $f => $flaga_zdj) {
            echo '    <div class="slider-slide" style="background-image: url(\'data/' . $art . '/' . rawurlencode($f) . '\'); background-size: contain;"></div>' . "\n";
          }
          if (count($lista_zdjec) > 1) {
            echo "  </div>\n";
            echo '  <div class="slider-btn slider-btn-prev"></div>' . "\n";
            echo '  <div class="slider-btn slider-btn-next"></div>' . "\n";
          }
          echo "</div>\n";
          if (count($lista_zdjec) > 1) echo "<script>var slide = new SimpleSlider('.simple-slider-{$licznik}', {autoplay: false, speed: 700});</script>\n";
        }
        // SLAJDY STOP

        if ($isadmin) {
          echo "<p class=\"admintool\"><a href=\"./?action=zdjecia&amp;artid={$art}&amp;p={$p}\"><img src=\"attachadd.svg\"></a></p>\n";
        }
        echo "</div>\n";
      }
      echo '<p class="paginacja">';
      $listastron = ListaStronDoPaginacji($p, $liczbastron);
      foreach ($listastron as $s) {
        if ($s > 0) {
          $class = '';
          if (($s == $p) || (($p == 0) && ($s == $liczbastron))) $class = 'class="curpage" ';
          echo "<a {$class}href=\"" . PaginationLink($s, $liczbastron) . "\">{$s}</a> ";
        } else {
          echo "&hellip; ";
        }
      }
      echo "</p>\n";

      BOTTOM:
    ?>
    </div>
  </body>
</html>
